==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/GetAgentPoolPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.GetAgentPoolPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property agentPoolName The name of the agent pool.
 * @property registryName The name of the container registry.
 * @property resourceGroupName The name of the resource group to which the container registry belongs.
 */
public data class GetAgentPoolPlainArgs(
    public val agentPoolName: String,
    public val registryName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.GetAgentPoolPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.GetAgentPoolPlainArgs =
        com.pulumi.azurenative.containerregistry.inputs.GetAgentPoolPlainArgs.builder()
            .agentPoolName(agentPoolName.let({ args0 -> args0 }))
            .registryName(registryName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetAgentPoolPlainArgs].
 */
@PulumiTagMarker
public class GetAgentPoolPlainArgsBuilder internal constructor() {
    private var agentPoolName: String? = null

    private var registryName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the agent pool.
     */
    @JvmName("jrqdtcyuxnmlbpvw")
    public suspend fun agentPoolName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.agentPoolName = mapped
    }

    /**
     * @param value The name of the container registry.
     */
    @JvmName("kigxgmayihphrigd")
    public suspend fun registryName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.registryName = mapped
    }

    /**
     * @param value The name of the resource group to which the container registry belongs.
     */
    @JvmName("hrsdogesnidxixpg")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetAgentPoolPlainArgs = GetAgentPoolPlainArgs(
        agentPoolName = agentPoolName ?: throw PulumiNullFieldException("agentPoolName"),
        registryName = registryName ?: throw PulumiNullFieldException("registryName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerregistry/kotlin/inputs/GetAgentPoolPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerregistry.kotlin.inputs

import com.pulumi.azurenative.containerregistry.inputs.GetAgentPoolPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property agentPoolName The name of the agent pool.
 * @property registryName The name of the container registry.
 * @property resourceGroupName The name of the resource group to which the container registry belongs.
 */
public data class GetAgentPoolPlainArgs(
    public val agentPoolName: String,
    public val registryName: String,
    public val resourceGroupName: String,
) : ConvertibleToJava<com.pulumi.azurenative.containerregistry.inputs.GetAgentPoolPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.containerregistry.inputs.GetAgentPoolPlainArgs =
        com.pulumi.azurenative.containerregistry.inputs.GetAgentPoolPlainArgs.builder()
            .agentPoolName(agentPoolName.let({ args0 -> args0 }))
            .registryName(registryName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetAgentPoolPlainArgs].
 */
@PulumiTagMarker
public class GetAgentPoolPlainArgsBuilder internal constructor() {
    private var agentPoolName: String? = null

    private var registryName: String? = null

    private var resourceGroupName: String? = null

    /**
     * @param value The name of the agent pool.
     */
    @JvmName("clrogxrwmflmikkp")
    public suspend fun agentPoolName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.agentPoolName = mapped
    }

    /**
     * @param value The name of the container registry.
     */
    @JvmName("hcgcxuxvbvvearxf")
    public suspend fun registryName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.registryName = mapped
    }

    /**
     * @param value The name of the resource group to which the container registry belongs.
     */
    @JvmName("puxreeaorhiemvet")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    internal fun build(): GetAgentPoolPlainArgs = GetAgentPoolPlainArgs(
        agentPoolName = agentPoolName ?: throw PulumiNullFieldException("agentPoolName"),
        registryName = registryName ?: throw PulumiNullFieldException("registryName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
    )
}
